==> haskell-unagi-streams-0.2.7-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-3PVAGUdwww2BaILZJBHkDv
key:                  unagi-streams-0.2.7-3PVAGUdwww2BaILZJBHkDv
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  1b55e0f129217150f40d39f73169b47d
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-3PVAGUdwww2BaILZJBHkDv
depends:
    base-4.17.2.1 io-streams-1.5.2.2-LJiozhSfmAG2P8ZUE6cv8c
    unagi-chan-0.4.1.4-ALYdjA5q0Tc23yoqHnkC0k

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unagi-streams-0.2.7-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unagi-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unagi-streams
version:              0.2.7
visibility:           public
id:                   unagi-streams-0.2.7-DUNc3ElqY6iAcxpaPDHO03
key:                  unagi-streams-0.2.7-DUNc3ElqY6iAcxpaPDHO03
license:              BSD-3-Clause
copyright:            Bitnomial, Inc. (c) 2016
maintainer:           luke@bitnomial.com
author:               Luke Hoersten
homepage:             https://github.com/bitnomial/unagi-streams
synopsis:             Unagi Chan IO-Streams
description:
    Io-streams chans implemented underneath with
    unagi-chans. This library is a straight port of
    the default io-streams chan implementation.

category:             IO-Streams, Concurrency
abi:                  bd4349baa265f6745e976584caaf6848
exposed:              True
exposed-modules:
    System.IO.Streams.Concurrent.Unagi
    System.IO.Streams.Concurrent.Unagi.Bounded

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unagi-streams-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unagi-streams
hs-libraries:         HSunagi-streams-0.2.7-DUNc3ElqY6iAcxpaPDHO03
depends:
    base-4.17.2.1 io-streams-1.5.2.2-BnxLvKN1XwkGmzDXcimoxX
    unagi-chan-0.4.1.4-KRGZym3PvhCKRekVNoNKfn

haddock-interfaces:
    /usr/share/doc/haskell-unagi-streams/html/unagi-streams.haddock

haddock-html:         /usr/share/doc/haskell-unagi-streams/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
